# rawphoto

**NOTE:** This project has now been deprecated by
[rawkit](https://github.com/photoshell/rawkit), a libraw wrapper. It will be
kept around for educational purposes, and may even be developed further.
Patches are still welcome, but you should probably not use this for any serious
work.

[![Build Status](https://travis-ci.org/photoshell/rawphoto.svg)](https://travis-ci.org/photoshell/rawphoto)
[![Coverage Status](https://coveralls.io/repos/photoshell/rawphoto/badge.svg?branch=master)](https://coveralls.io/r/photoshell/rawphoto?branch=master)
[![Latest Version](https://pypip.in/version/rawphoto/badge.svg)](https://pypi.python.org/pypi/rawphoto/)
[![Development Status](https://pypip.in/status/rawphoto/badge.svg)](https://pypi.python.org/pypi/rawphoto/)

This package facilitates the parsing of raw photo formats in Python.

Supported formats include:

  - Canon CR2
  - Nikon NEF

## Installing

Using pip:

    $ pip install rawphoto
